@@ -161,6 +161,9 @@ class FormatDecisionState(object):
         if not style.Get('ALLOW_SPLIT_BEFORE_DICT_VALUE'):
           return False
 
+    if previous and previous.value == '.' and current.value == '.':
+      return False
+
     return current.can_break_before
 
   def MustSplit(self):
@@ -177,7 +180,8 @@ class FormatDecisionState(object):
     if not previous:
       return False
 
-    if self.stack[-1].split_before_closing_bracket and current.value in '}]':
+    if (self.stack[-1].split_before_closing_bracket and
+        current.value in '}]' and style.Get('SPLIT_BEFORE_CLOSING_BRACKET')):
       # Split before the closing bracket if we can.
       return current.node_split_penalty != split_penalty.UNBREAKABLE
 
